@@ -22,7 +22,7 @@ MitsubishiTV1::MitsubishiTV1(
 
   np->setPreData(0xE2, 8);
 
-  np->setMinimumRepetitions(1);
+//  np->setMinimumRepetitions(1);
 
   addKey("POWER", Power_Key, 0x40, 8);
   addKey("0", Zero_Key, 0x90, 8);
@@ -126,7 +126,7 @@ MitsubishiVCR1::MitsubishiVCR1(
 
   np->setPreData(0xEA, 8);
 
-  np->setMinimumRepetitions(1);
+//  np->setMinimumRepetitions(1);
 
   addKey("POWER", Power_Key, 0x40, 8);
   addKey("CH-", ChannelDown_Key, 0x48, 8);
